﻿''' <summary>
''' 枠線に関するプロパティ画面です。
''' </summary>
''' <remarks></remarks>
Public Class BorderProperty

    ''' <summary>
    ''' Load
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 2008/09/12 NiceVision
    ''' </remarks>
    Private Sub BorderProperty_Load(ByVal sender As Object, ByVal e As System.EventArgs) _
    Handles Me.Load
        '初期化処理を行います。
        Call Initialize()
    End Sub

    ''' <summary>
    ''' 初期化処理
    ''' </summary>
    ''' <remarks>
    ''' 2008/09/12 NiceVision
    ''' </remarks>
    Private Sub Initialize()

        'タイトルです。
        Me.lblTitle.Text = "枠線に関するプロパティ"

        'プロパティの名称です。
        Me.lblPropertyName1.Text = "BorderColorDarkプロパティ"
        Me.lblPropertyName2.Text = "BorderColorLightプロパティ"
        Me.lblPropertyName3.Text = "BorderStyleプロパティ"
        Me.lblPropertyName4.Text = "BorderWidthプロパティ"

        'プロパティの説明です。
        Me.lblBorderColorDark.Text = String.Concat("枠線の濃い色を取得および設定します。", vbCrLf _
                        , "BorderStyleプロパティがNoneの場合、このプロパティは無視されます。", vbCrLf _
                        , "既定値：System.Drawing.Color.Black")
        Me.lblBorderColorLight.Text = String.Concat("枠線の明るい色を取得および設定します。", vbCrLf _
                        , "BorderStyleプロパティがGroove、Ridge、Inset、Outsetの場合、このプロパティは有効です。", vbCrLf _
                        , "既定値：System.Drawing.Color.White")
        Me.lblBorderStyle.Text = String.Concat("枠線の種類を取得および設定します。", vbCrLf _
                        , "既定値：BorderStyleType.Solid")
        Me.lblBorderWidth.Text = String.Concat("枠線の太さを取得および設定します。", vbCrLf, "既定値：1")

    End Sub

    ''' <summary>
    ''' 枠線の太さを設定します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 2008/09/11 NiceVision
    ''' </remarks>
    Private Sub nudBorderWidth_ValueChanged(ByVal sender As Object, ByVal e As System.EventArgs) _
    Handles nudBorderWidth.ValueChanged
        Me.rspSampleBorder.BorderWidth = Me.nudBorderWidth.Value
    End Sub

    ''' <summary>
    ''' 枠線の変更色を設定します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 2008/09/11 NiceVision
    ''' </remarks>
    Private Sub cmdBorderColor_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) _
    Handles cmdBorderColorDark.Click, cmdBorderColorLight.Click

        Dim color As System.Drawing.Color
        Using frmColorDialog As New ColorDialog()
            If frmColorDialog.ShowDialog() <> DialogResult.OK Then
                Return
            End If
            color = frmColorDialog.Color
        End Using 'frmColorDialog


        'カラーサンプル用シェイプに変更色を設定します。
        If sender.Equals(Me.cmdBorderColorDark) Then
            Me.rspColorSample1.FillColor1 = color
        ElseIf sender.Equals(Me.cmdBorderColorLight) Then
            Me.rspColorSample2.FillColor1 = color
        End If

    End Sub

    ''' <summary>
    ''' グループボックス内のシェイプの枠線を変更色に設定します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 2008/09/11 NiceVision
    ''' </remarks>
    Private Sub cmdChangeColor_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) _
    Handles cmdChangeColor.Click
        '枠線の色を設定します。
        Call SetBorderColor(Me.rspColorSample1.FillColor1, Me.rspColorSample2.FillColor1)
    End Sub

    ''' <summary>
    ''' グループボックス内のシェイプの枠線を、初期値に戻します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 2008/09/11 NiceVision
    ''' </remarks>
    Private Sub cmdInitColor_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) _
    Handles cmdInitColor.Click
        'カラーサンプル用シェイプの色を設定します。
        Me.rspColorSample1.FillColor1 = Color.Black
        Me.rspColorSample2.FillColor1 = Color.White
        '枠線の色を設定します。
        Call SetBorderColor(Me.rspColorSample1.FillColor1, Me.rspColorSample2.FillColor1)
    End Sub

    ''' <summary>
    ''' グループボックス内のシェイプの枠線の色を設定します。
    ''' </summary>
    ''' <param name="color1">BorderColorDarkプロパティに適用する色</param>
    ''' <param name="color2">BorderColorLightプロパティに適用する色</param>
    ''' <remarks>
    ''' 2008/09/11 NiceVision
    ''' </remarks>
    Private Sub SetBorderColor(ByVal color1 As System.Drawing.Color, ByVal color2 As System.Drawing.Color)
        'BorderStyleグループボックス
        For Each control As System.Windows.Forms.Control In Me.grpBorderStyle.Controls
            If TypeOf (control) Is Nicevision.NvShapes.RectangleShape Then
                CType(control, Nicevision.NvShapes.RectangleShape).BorderColorDark = color1
                CType(control, Nicevision.NvShapes.RectangleShape).BorderColorLight = color2
            End If
        Next control

        'BorderWidthグループボックス
        For Each control As System.Windows.Forms.Control In Me.grpBorderWidth.Controls
            If TypeOf (control) Is Nicevision.NvShapes.RectangleShape Then
                CType(control, Nicevision.NvShapes.RectangleShape).BorderColorDark = color1
                CType(control, Nicevision.NvShapes.RectangleShape).BorderColorLight = color2
            End If
        Next control
    End Sub

End Class